@@ -14,10 +14,10 @@ use 5.010_000;
 use strict;
 use warnings;
 use perl5 0.03 ();
-use perl5i v2.6.1 ();
+use perl5i 2.6.1 ();
 use perl5i::latest ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub import {
     @_ = ('perl5i::latest');
